<?php require_once( 'couch/cms.php' ); ?>
<cms:template title='Manage Profile' hidden='1' order='100' />

<!-- DON'T FORGET THIS CHECK! Only logged-in users allowed access. -->
<cms:if k_logged_out >
    <cms:redirect k_login_link />
</cms:if>

<!DOCTYPE html>
<html lang="en">
    <head>
        <meta charset="UTF-8" />
        <title>Manage Profile</title>

        <style>
            #manage_profile {text-align:center;}
            #manage_profile label {display:block;}
            #success {color:green;}
            .desc {color:#777777; font-size:75%}
            .error {color:red; font-size:75%; display:block; margin-top:-12px; margin-bottom:6px;}
            input {width:200px; margin-bottom:12px;}
        </style>
    </head>

    <body>
        <p style="text-align:right;">Hello, <cms:show k_user_title/><br/>
        <a href="<cms:show k_logout_link />">Logout</a></p>


        <cms:form id="manage_profile" action="" method="post" anchor="0" autocomplete="off">
            
            <cms:if k_success >
                <!-- 
                    This is where the meat of the processing lies, 
                    which is not much really as we simply piggyback on the built-in user object.
                    Most of our code is concerned only will passing on the submitted values to the user object
                    and then checking for errors on saving it.
                -->
                <cms:php>
                    global $AUTH, $CTX;
                    
                    // get current user object
                    $user = &$AUTH->user;
                    if( $user->id == -1 ){  die;  } // User not logged-in. Can happen only if login check not placed in template
                    $user->populate_fields();
                    
                    // set object's fields with submitted values
                    for( $x=0; $x<count($user->fields); $x++ ){
                        $f = &$user->fields[$x];
                        $submitted_value = $CTX->get( 'frm_'.$f->name, 1 );
                        if( strlen($submitted_value) ){
                            $f->store_posted_changes( $submitted_value ); 
                        }
                        unset( $f );
                    }
                    
                    // try saving..
                    $errors = $user->save();
                    
                    // success or error?
                    if( $errors ){
                        $sep = '';
                        $form_separator = $CTX->get('k_cur_form_separator');
                        
                        $str_err = '';
                        for( $x=0; $x<count($user->fields); $x++ ){
                            $f = &$user->fields[$x];
                            if( $f->err_msg ){
                                $CTX->set( 'k_error_'.$f->name, $f->err_msg );
                                $str_err .= $sep . '<b>' . $f->name . ':</b> ' . $f->err_msg;
                                $sep = $form_separator;
                            }
                            unset( $f );
                        }
                        $CTX->set( 'k_success', '' );
                        $CTX->set( 'k_error', $str_err );
                    }
                    else{
                        // great!
                        $CTX->set( 'k_profile_modified', '1' );
                    }
                </cms:php>
                
                <cms:if k_profile_modified >
                    <!-- Everything ok. Refresh and report success -->
                    <cms:set_flash name='show_success' value='1' />
                    <cms:redirect k_page_link />
                </cms:if>
            </cms:if>
        
            <h1>Mange Your Profile</h1>
 
            
            <cms:set show_success="<cms:get_flash 'show_success' />" />
            <cms:if show_success >
                <p id="success"><strong>Success:</strong> Your profile has been modified.</p>
            </cms:if>

            <label>Display Name <span class="desc"><i>(required)</i></span> <br/>
                <cms:input type="text" name="k_title" required="1" value=k_user_title autocomplete="off" />
                <cms:if k_error_k_title ><span class="error"><i>(<cms:show k_error_k_title />)</i></span></cms:if>
            </label> 
            
            <label>E-Mail <span class="desc"><i>(required)</i></span><br/>
                <cms:input type="text" name="k_email" required="1" value=k_user_email autocomplete="off" />
                <cms:if k_error_k_email ><span class="error"><i>(<cms:show k_error_k_email />)</i></span></cms:if>
            </label> 
            
            <label>New Password<br/>
                <span class="desc"><i>(If you would like to change the password type a new one. Otherwise leave this blank.)</i></span><br/>
                <cms:input type="password" name="k_password" value="" autocomplete="off" autofocus="autofocus" />
                <cms:if k_error_k_password ><span class="error"><i>(<cms:show k_error_k_password />)</i></span></cms:if>
            </label>
            
            <label>Repeat Password<br/>
                <cms:input type="password" name="k_password2" autocomplete="off" />
                <cms:if k_error_k_password2 ><span class="error"><i>(<cms:show k_error_k_password2 />)</i></span></cms:if>
            </label> 
            
            <br/>
            <input type="submit" value="Modify"/>
        </cms:form>


    </body>
</html>
<?php COUCH::invoke(); ?>